@@ -17,6 +17,9 @@ UNIQUE = "True"
 
 #########
 
+def listdb():
+    return [".".join(x.split(".")[:-1]) for x in os.listdir() if x.endswith(".qtz")]
+
 def binary_search(arr, x):
     n = len(arr)
     lo = 0
